# Resources

Supporting documentation including error handling and good practices.

```{toctree}
:maxdepth: 1
good_to_know
../changelog
```

> **Note:** For contributing guidelines, see main [Contributing Guide](https://github.com/fgcz/bfabricPy/blob/main/CONTRIBUTING.md) in the repository root.

## Overview

This section contains resources to help you use bfabricPy effectively:

| Resource | Description | For |
| -------------------------------------------- | ---------------------------------------------------- | --------------------------- |
| **[Good to Know](good_to_know)** | Useful tips and important notes | All users |
| **[Contributing](../../../CONTRIBUTING)** | How to contribute to bfabricPy | Contributors |
| **[Changelog](../changelog)** | Version history and changes | All users |

## Quick Links

### I'm Getting Started

- [Quick Start Tutorial](../../getting_started/quick_start)
- [Configuration Guide](../../getting_started/configuration)

### I Want to Improve My Code

- [Good to Know](good_to_know) - Useful tips and notes
- [User Guides](../../user_guides/index) - Task-based tutorials

### I Want to Contribute

- [Contributing Guide](https://github.com/fgcz/bfabricPy/blob/main/CONTRIBUTING.md) - How to contribute (repository root)
- [Changelog](../changelog.md) - Recent changes
